'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
var data = '{service}:{user}?secret={secret}&issuer={service}';

/**
 * Generates an otpauth uri
 *
 * @namespace otplib/impl/authenticator
 * @module impl/authenticator/keyuri
 * @param {string} user - the name/id of your user
 * @param {string} service - the name of your service
 * @param {string} secret - your secret that is used to generate the token
 * @return {string} otpauth uri. Example: otpauth://totp/user:localhost?secet=NKEIBAOUFA
 */
function keyuri() {
  var user = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : 'user';
  var service = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 'service';
  var secret = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : '';

  var protocol = 'otpauth://totp/';
  var value = data.replace('{user}', user).replace('{secret}', secret).replace(/{service}/g, service);

  return protocol + value;
}

exports.default = keyuri;